@@ -16,28 +16,32 @@ import logging
 import re
 import warnings
 
+from django.conf import settings as dj_settings
 from django.core.signals import request_finished
 from django.db import models, transaction, IntegrityError
 from django.db.models import Sum
 from django.db.models.expressions import F, ExpressionNode
 from django.db.models.signals import post_save, post_delete, post_init, class_prepared
+from django.utils import timezone
+from django.utils.datastructures import SortedDict
 from django.utils.encoding import force_unicode, smart_str
 
 from raven.utils.encoding import to_string
 from sentry import app
 from sentry.conf import settings
+from sentry.constants import STATUS_RESOLVED, STATUS_UNRESOLVED
 from sentry.processors.base import send_group_processors
 from sentry.signals import regression_signal
 from sentry.tasks.index import index_event
 from sentry.utils.cache import cache, Lock
-from sentry.utils.dates import utc_to_local, get_sql_date_trunc
+from sentry.utils.dates import get_sql_date_trunc
 from sentry.utils.db import get_db_engine, has_charts, resolve_expression_node
 from sentry.utils.queue import maybe_delay
 
 logger = logging.getLogger('sentry.errors')
 
 UNSAVED = dict()
-
+MAX_TAG_LENGTH = 200
 
 def get_checksum_from_event(event):
     for interface in event.interfaces.itervalues():
@@ -318,7 +322,7 @@ class ChartMixin(object):
         if not has_charts(db):
             return []
 
-        today = datetime.datetime.now().replace(microsecond=0, second=0, minute=0)
+        today = timezone.now().replace(microsecond=0, second=0, minute=0)
         min_date = today - datetime.timedelta(days=max_days)
 
         if max_days > 30:
@@ -402,7 +406,7 @@ class GroupManager(BaseManager, ChartMixin):
         logger_name = kwargs.pop('logger', None) or settings.DEFAULT_LOGGER_NAME
         server_name = kwargs.pop('server_name', None)
         site = kwargs.pop('site', None)
-        date = kwargs.pop('timestamp', None) or datetime.datetime.utcnow()
+        date = kwargs.pop('timestamp', None) or timezone.now()
         checksum = kwargs.pop('checksum', None)
         tags = kwargs.pop('tags', [])
 
@@ -412,7 +416,12 @@ class GroupManager(BaseManager, ChartMixin):
 
         # We must convert date to local time so Django doesn't mess it up
         # based on TIME_ZONE
-        date = utc_to_local(date)
+        if dj_settings.TIME_ZONE:
+            if not timezone.is_aware(date):
+                date = date.replace(tzinfo=timezone.utc)
+        elif timezone.is_aware(date):
+            date = date.replace(tzinfo=None)
+
         data = kwargs
 
         kwargs = {
@@ -494,8 +503,7 @@ class GroupManager(BaseManager, ChartMixin):
         return event
 
     def _create_group(self, event, tags=None, **kwargs):
-        from sentry.models import ProjectCountByMinute, MessageCountByMinute, STATUS_RESOLVED, \
-          STATUS_UNRESOLVED
+        from sentry.models import ProjectCountByMinute, MessageCountByMinute
 
         date = event.datetime
         time_spent = event.time_spent
@@ -535,6 +543,10 @@ class GroupManager(BaseManager, ChartMixin):
                 'last_seen': max(event.datetime, group.last_seen),
                 'score': ScoreClause(group),
             }
+            message = kwargs.get('message')
+            if message:
+                extra['message'] = message
+
             if group.status == STATUS_RESOLVED:
                 # Group has changed from resolved -> unresolved
                 is_new = True
@@ -604,6 +616,9 @@ class GroupManager(BaseManager, ChartMixin):
         date = group.last_seen
 
         for key, value in itertools.ifilter(bool, tags):
+            if len(value) > MAX_TAG_LENGTH:
+                continue
+
             # TODO: FilterKey and FilterValue queries should be create's under a try/except
             FilterKey.objects.get_or_create(
                 project=project,
@@ -1013,3 +1028,32 @@ class FilterKeyManager(BaseManager):
             result = list(self.filter(project=project).values_list('key', flat=True))
             cache.set(key, result, 60)
         return result
+
+
+class TeamManager(BaseManager):
+    def get_for_user(self, user, access=None):
+        """
+        Returns a SortedDict of all teams a user has some level of access to.
+
+        Each <Team> returned has a ``membership`` attribute which holds the
+        <TeamMember> instance.
+        """
+        from sentry.models import TeamMember
+
+        if access is None or not user.is_authenticated():
+            return SortedDict()
+
+        qs = TeamMember.objects.filter(
+            user=user,
+            is_active=True,
+        ).select_related('team')
+        if access is not None:
+            qs = qs.filter(type__lte=access)
+
+        results = SortedDict()
+        for tm in sorted(qs, key=lambda x: x.team.name):
+            team = tm.team
+            team.membership = tm
+            results[team.slug] = team
+
+        return results
