@@ -256,8 +256,13 @@ class IPlugin(local):
         Given a template name, and an optional context (dictionary), returns a
         ready-to-render response.
 
+        Default context includes the plugin instance.
+
         >>> plugin.render('template.html', {'hello': 'world'})
         """
+        if context is None:
+            context = {}
+        context['plugin'] = self
         return Response(template, context)
 
     # The following methods are specific to web requests
@@ -280,6 +285,8 @@ class IPlugin(local):
         return self.description
 
     def get_view_response(self, request, group):
+        from sentry.permissions import can_admin_group
+
         self.selected = request.path == self.get_url(group)
 
         if not self.selected:
@@ -297,8 +304,10 @@ class IPlugin(local):
             raise NotImplementedError('Please use self.render() when returning responses.')
 
         return response.respond(request, {
+            'plugin': self,
             'project': group.project,
             'group': group,
+            'can_admin_event': can_admin_group(request.user, group),
         })
 
     def view(self, request, group, **kwargs):
