@@ -11,8 +11,8 @@ from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
 from django.views.decorators.csrf import csrf_protect
 
-from sentry.models import TeamMember, MEMBER_OWNER, \
-  ProjectKey, Team, FilterKey
+from sentry.constants import MEMBER_OWNER, MEMBER_USER
+from sentry.models import TeamMember, ProjectKey, Team, FilterKey
 from sentry.permissions import can_create_projects, can_remove_project, can_create_teams
 from sentry.plugins import plugins
 from sentry.plugins.helpers import set_option, get_option
@@ -23,7 +23,7 @@ from sentry.web.forms.projects import NewProjectForm, NewProjectAdminForm,\
   ProjectTagsForm
 from sentry.web.forms.teams import NewTeamForm, SelectTeamForm
 from sentry.web.helpers import render_to_response, get_project_list, \
-  plugin_config, get_team_list
+  plugin_config
 
 
 @login_required
@@ -55,7 +55,7 @@ def new_project(request):
         return HttpResponseRedirect(reverse('sentry'))
 
     allow_create_teams = can_create_teams(request.user)
-    team_list = get_team_list(request.user)
+    team_list = Team.objects.get_for_user(request.user)
 
     if request.user.has_perm('sentry.can_add_project') and User.objects.all()[0:2] == 2:
         project_form_cls = NewProjectAdminForm
@@ -107,13 +107,9 @@ def new_project(request):
     }, request)
 
 
-@login_required
 @has_access(MEMBER_OWNER)
 @csrf_protect
 def remove_project(request, project):
-    if project.is_default_project():
-        return HttpResponseRedirect(reverse('sentry-project-list'))
-
     if not can_remove_project(request.user, project):
         return HttpResponseRedirect(reverse('sentry'))
 
@@ -144,7 +140,6 @@ def remove_project(request, project):
     return render_to_response('sentry/projects/remove.html', context, request)
 
 
-@login_required
 @has_access(MEMBER_OWNER)
 @csrf_protect
 def manage_project(request, project):
@@ -152,7 +147,7 @@ def manage_project(request, project):
     if result is False and not request.user.has_perm('sentry.can_change_project'):
         return HttpResponseRedirect(reverse('sentry'))
 
-    team_list = get_team_list(request.user)
+    team_list = Team.objects.get_for_user(request.user, MEMBER_OWNER)
 
     if request.user.has_perm('sentry.can_change_project'):
         form_cls = EditProjectAdminForm
@@ -187,8 +182,7 @@ def manage_project(request, project):
     return render_to_response('sentry/projects/manage.html', context, request)
 
 
-@login_required
-@has_access
+@has_access(MEMBER_USER)
 def client_help(request, project):
     try:
         key = ProjectKey.objects.get(user=request.user, project=project)
@@ -209,7 +203,6 @@ def client_help(request, project):
     return render_to_response('sentry/projects/client_help.html', context, request)
 
 
-@login_required
 @has_access(MEMBER_OWNER)
 def manage_project_tags(request, project):
     tag_list = FilterKey.objects.all_keys(project)
@@ -235,7 +228,6 @@ def manage_project_tags(request, project):
     return render_to_response('sentry/projects/manage_tags.html', context, request)
 
 
-@login_required
 @has_access(MEMBER_OWNER)
 @csrf_protect
 def configure_project_plugin(request, project, slug):
@@ -271,7 +263,6 @@ def configure_project_plugin(request, project, slug):
     return render_to_response('sentry/projects/plugins/configure.html', context, request)
 
 
-@login_required
 @has_access(MEMBER_OWNER)
 @csrf_protect
 def manage_plugins(request, project):
